@@ -73,11 +73,17 @@ var _ = BeforeSuite(func() {
 	readerIDP := idpconfig.GetScenarioResourcesReader()
 	clusterOAuthCRD, err := getCRD(readerIDP, "crd/bases/identityconfig.identitatem.io_clusteroauths.yaml")
 	Expect(err).Should(BeNil())
+	authRealmCRD, err := getCRD(readerIDP, "crd/bases/identityconfig.identitatem.io_authrealms.yaml")
+	Expect(err).Should(BeNil())
+	strategyCRD, err := getCRD(readerIDP, "crd/bases/identityconfig.identitatem.io_strategies.yaml")
+	Expect(err).Should(BeNil())
 
 	By("bootstrapping test environment")
 	testEnv = &envtest.Environment{
 		CRDs: []*apiextensionsv1.CustomResourceDefinition{
 			clusterOAuthCRD,
+			authRealmCRD,
+			strategyCRD,
 		},
 		CRDDirectoryPaths: []string{
 			//DV added this line and copyed the authrealms CRD
@@ -156,8 +162,9 @@ var _ = AfterSuite(func() {
 
 var _ = Describe("Process clusterOAuth for Strategy backplane: ", func() {
 	AuthRealmName := "my-authrealm"
+	AuthRealmNamespace := "my-authrealm-ns"
 	AuthRealmName2 := "my-authrealm" + "-2"
-	//StrategyName := AuthRealmName + "-backplane"
+	StrategyName := AuthRealmName + "-backplane"
 	//ClusterOAuthName1 := StrategyName + "-1"
 	//ClusterOAuthName2 := StrategyName + "-2"
 	ClusterName := "my-cluster"
@@ -166,6 +173,16 @@ var _ = Describe("Process clusterOAuth for Strategy backplane: ", func() {
 	// MyIDPName3 := "my-idp" + "-3"
 
 	It("process a ClusterOAuth CR", func() {
+		By(fmt.Sprintf("creation of authrealm namespace %s", ClusterName), func() {
+			ns := &corev1.Namespace{
+				ObjectMeta: metav1.ObjectMeta{
+					Name: AuthRealmNamespace,
+				},
+			}
+			err := k8sClient.Create(context.TODO(), ns)
+			Expect(err).To(BeNil())
+		})
+
 		By(fmt.Sprintf("creation of cluster namespace %s", ClusterName), func() {
 			ns := &corev1.Namespace{
 				ObjectMeta: metav1.ObjectMeta{
@@ -193,6 +210,33 @@ var _ = Describe("Process clusterOAuth for Strategy backplane: ", func() {
 
 		})
 
+		var authRealm *identitatemv1alpha1.AuthRealm
+		By(fmt.Sprintf("creation of AuthRealm in cluster namespace %s", ClusterName), func() {
+			authRealm = &identitatemv1alpha1.AuthRealm{
+				TypeMeta: metav1.TypeMeta{
+					APIVersion: corev1.SchemeGroupVersion.String(),
+					Kind:       "AuthRealm",
+				},
+				ObjectMeta: metav1.ObjectMeta{
+					Name:      AuthRealmName,
+					Namespace: AuthRealmNamespace,
+				},
+				Spec: identitatemv1alpha1.AuthRealmSpec{
+					RouteSubDomain: "myroute",
+				},
+			}
+			err := k8sClient.Create(context.TODO(), authRealm)
+			Expect(err).To(BeNil())
+			patch := client.MergeFrom(authRealm.DeepCopy())
+			authRealm.Status.Strategies = []identitatemv1alpha1.AuthRealmStrategyStatus{
+				{
+					Name: "my-authrealm-backplane",
+				},
+			}
+			err = k8sClient.Status().Patch(context.TODO(), authRealm, patch)
+			Expect(err).To(BeNil())
+		})
+
 		By(fmt.Sprintf("creation of ClusterOAuth for managed cluster %s", ClusterName), func() {
 			clusterOAuth := &identitatemv1alpha1.ClusterOAuth{
 				TypeMeta: metav1.TypeMeta{
@@ -204,6 +248,16 @@ var _ = Describe("Process clusterOAuth for Strategy backplane: ", func() {
 					Namespace: ClusterName,
 				},
 				Spec: identitatemv1alpha1.ClusterOAuthSpec{
+					AuthRealmReference: identitatemv1alpha1.RelatedObjectReference{
+						Kind:      "AuthRealm",
+						Name:      AuthRealmName,
+						Namespace: AuthRealmNamespace,
+					},
+					StrategyReference: identitatemv1alpha1.RelatedObjectReference{
+						Kind:      "Strategy",
+						Name:      StrategyName,
+						Namespace: AuthRealmNamespace,
+					},
 					OAuth: &openshiftconfigv1.OAuth{
 						TypeMeta: metav1.TypeMeta{
 							APIVersion: openshiftconfigv1.SchemeGroupVersion.String(),
@@ -332,6 +386,15 @@ var _ = Describe("Process clusterOAuth for Strategy backplane: ", func() {
 			Expect(err).To(BeNil())
 		})
 
+		By("Checking Authrealm status", func() {
+			err := k8sClient.Get(context.TODO(), client.ObjectKey{
+				Name:      AuthRealmName,
+				Namespace: AuthRealmNamespace,
+			}, authRealm)
+			Expect(err).To(BeNil())
+			Expect(len(authRealm.Status.Strategies[0].Clusters[0].ClusterOAuth.Conditions)).To(Equal(1))
+		})
+
 		var secret2 *corev1.Secret
 		By(fmt.Sprintf("creation of IDP secret 2 in cluster namespace %s", ClusterName), func() {
 			secret2 = &corev1.Secret{
@@ -360,6 +423,16 @@ var _ = Describe("Process clusterOAuth for Strategy backplane: ", func() {
 					Namespace: ClusterName,
 				},
 				Spec: identitatemv1alpha1.ClusterOAuthSpec{
+					AuthRealmReference: identitatemv1alpha1.RelatedObjectReference{
+						Kind:      "AuthRealm",
+						Name:      AuthRealmName,
+						Namespace: AuthRealmNamespace,
+					},
+					StrategyReference: identitatemv1alpha1.RelatedObjectReference{
+						Kind:      "Strategy",
+						Name:      StrategyName,
+						Namespace: AuthRealmNamespace,
+					},
 					OAuth: &openshiftconfigv1.OAuth{
 						TypeMeta: metav1.TypeMeta{
 							APIVersion: openshiftconfigv1.SchemeGroupVersion.String(),
