@@ -12,15 +12,19 @@ import (
 	// corev1 "k8s.io/api/core/v1"
 
 	apiextensionsclient "k8s.io/apiextensions-apiserver/pkg/client/clientset/clientset"
+	"k8s.io/apimachinery/pkg/api/equality"
 	"k8s.io/apimachinery/pkg/api/errors"
 	"k8s.io/apimachinery/pkg/runtime"
 	"k8s.io/apimachinery/pkg/types"
 	"k8s.io/client-go/dynamic"
 	"k8s.io/client-go/kubernetes"
 	ctrl "sigs.k8s.io/controller-runtime"
+	"sigs.k8s.io/controller-runtime/pkg/builder"
 	"sigs.k8s.io/controller-runtime/pkg/client"
 	"sigs.k8s.io/controller-runtime/pkg/controller/controllerutil"
+	"sigs.k8s.io/controller-runtime/pkg/event"
 	"sigs.k8s.io/controller-runtime/pkg/handler"
+	"sigs.k8s.io/controller-runtime/pkg/predicate"
 	"sigs.k8s.io/controller-runtime/pkg/reconcile"
 	"sigs.k8s.io/controller-runtime/pkg/source"
 
@@ -101,7 +105,7 @@ func (r *PlacementDecisionReconciler) Reconcile(ctx context.Context, req ctrl.Re
 
 	//if deletetimestamp then delete dex namespace
 	if instance.DeletionTimestamp != nil {
-		if err := r.processPlacementDecisionDeletion(instance); err != nil {
+		if err := r.processPlacementDecisionDeletion(instance, false); err != nil {
 			return reconcile.Result{}, err
 		}
 		r.Log.Info("remove finalizer", "Finalizer:", helpers.AuthrealmFinalizer, "name", instance.Name, "namespace", instance.Namespace)
@@ -112,52 +116,68 @@ func (r *PlacementDecisionReconciler) Reconcile(ctx context.Context, req ctrl.Re
 		return reconcile.Result{}, nil
 	}
 
+	if err := r.processPlacementDecisionUpdate(instance); err != nil {
+		return reconcile.Result{}, err
+	}
+	return reconcile.Result{}, nil
+
+}
+
+func (r *PlacementDecisionReconciler) processPlacementDecisionUpdate(placement *clusterv1alpha1.Placement) error {
 	//Add finalizer
-	r.Log.Info("add finalizer", "Finalizer:", helpers.AuthrealmFinalizer, "name", instance.Name, "namespace", instance.Namespace)
-	controllerutil.AddFinalizer(instance, helpers.AuthrealmFinalizer)
-	if err := r.Client.Update(context.TODO(), instance); err != nil {
-		return reconcile.Result{}, giterrors.WithStack(err)
+	r.Log.Info("add finalizer", "Finalizer:", helpers.AuthrealmFinalizer, "name", placement.Name, "namespace", placement.Namespace)
+	controllerutil.AddFinalizer(placement, helpers.AuthrealmFinalizer)
+	if err := r.Client.Update(context.TODO(), placement); err != nil {
+		return giterrors.WithStack(err)
 	}
 
 	//Check if the placementDecision is linked to a strategy
-	ok, err := r.isLinkedToStrategy(instance)
+	ok, err := r.isLinkedToStrategy(placement)
 	if !ok {
-		return reconcile.Result{}, nil
+		return nil
 	}
 	if err != nil {
-		return reconcile.Result{}, err
+		return err
 	}
 
-	strategy, err := r.GetStrategyFromPlacement(instance.Name, instance.Namespace)
+	strategies, err := r.GetStrategiesFromPlacement(placement)
 	if err != nil {
-		return reconcile.Result{}, err
+		return err
 	}
 
-	authRealm, err := helpers.GetAuthrealmFromStrategy(r.Client, strategy)
-	if err != nil {
-		return reconcile.Result{}, err
-	}
+	for i := range strategies.Items {
+		authRealm, err := helpers.GetAuthrealmFromStrategy(r.Client, &strategies.Items[i])
+		if err != nil {
+			return err
+		}
 
-	if err := r.processPlacementDecision(authRealm, instance); err != nil {
-		return reconcile.Result{}, err
+		if err := r.processPlacementDecision(authRealm, &strategies.Items[i], placement); err != nil {
+			return err
+		}
+		if err := r.updateAuthRealmStatusPlacementStatus(&strategies.Items[i], placement); err != nil {
+			return err
+		}
 	}
-
-	return ctrl.Result{}, nil
+	if err := r.processPlacementDecisionDeletion(placement, true); err != nil {
+		return err
+	}
+	return nil
 }
 
 //processPlacementDecision generates resources for the Backplane strategy
 func (r *PlacementDecisionReconciler) processPlacementDecision(
 	authRealm *identitatemv1alpha1.AuthRealm,
+	strategy *identitatemv1alpha1.Strategy,
 	placement *clusterv1alpha1.Placement) error {
 	r.Log.Info("run backplane strategy")
-	if err := r.syncDexClients(authRealm, placement); err != nil {
+	if err := r.syncDexClients(authRealm, strategy, placement); err != nil {
 		return err
 	}
 	return nil
 }
 
 func (r *PlacementDecisionReconciler) isLinkedToStrategy(placement *clusterv1alpha1.Placement) (bool, error) {
-	_, err := r.GetStrategyFromPlacement(placement.Name, placement.Namespace)
+	_, err := r.GetStrategiesFromPlacement(placement)
 	if err != nil {
 		if !errors.IsNotFound(err) {
 			return false, nil
@@ -169,10 +189,7 @@ func (r *PlacementDecisionReconciler) isLinkedToStrategy(placement *clusterv1alp
 	return true, giterrors.WithStack(err)
 }
 
-func (r *PlacementDecisionReconciler) processPlacementDecisionDeletion(placement *clusterv1alpha1.Placement) error {
-	r.Log.Info("start deletion of Placement",
-		"namespace", placement.Namespace,
-		"name", placement.Name)
+func (r *PlacementDecisionReconciler) processPlacementDecisionDeletion(placement *clusterv1alpha1.Placement, onlyIfAuthRealmDeleted bool) error {
 	ok, err := r.isLinkedToStrategy(placement)
 	if !ok {
 		return nil
@@ -181,15 +198,9 @@ func (r *PlacementDecisionReconciler) processPlacementDecisionDeletion(placement
 		return err
 	}
 
-	strategy, err := r.GetStrategyFromPlacement(placement.Name, placement.Namespace)
-	if err != nil {
-		return err
-	}
-
-	authRealm, err := helpers.GetAuthrealmFromStrategy(r.Client, strategy)
-	if err != nil {
-		return err
-	}
+	r.Log.Info("start deletion of Placement",
+		"namespace", placement.Namespace,
+		"name", placement.Name)
 
 	r.Log.Info("search placementdecisions in ns and label",
 		"namespace", placement.Namespace,
@@ -202,21 +213,11 @@ func (r *PlacementDecisionReconciler) processPlacementDecisionDeletion(placement
 	}
 	for _, placementDecision := range placementDecisions.Items {
 		for _, decision := range placementDecision.Status.Decisions {
-			if err := r.deleteConfig(authRealm, helpers.DexClientName(authRealm, decision.ClusterName), decision.ClusterName); err != nil {
+			if err := r.deleteConfig(decision.ClusterName, onlyIfAuthRealmDeleted); err != nil {
 				return err
 			}
 		}
 	}
-
-	//Remove the finalizers when there is no other placementDecisions for that placement.
-	// if len(placementDecisions.Items) == 1 {
-	// 	if err := helpers.RemovePlacementDecisionFinalizer(r.Client, r.Log, strategy, strategy); err != nil {
-	// 		return err
-	// 	}
-	// 	if err := helpers.RemovePlacementDecisionFinalizer(r.Client, r.Log, strategy, authRealm); err != nil {
-	// 		return err
-	// 	}
-	// }
 	return nil
 }
 
@@ -258,59 +259,81 @@ func (r *PlacementDecisionReconciler) SetupWithManager(mgr ctrl.Manager) error {
 		return err
 	}
 
+	authRealmPredicate := predicate.Predicate(predicate.Funcs{
+		GenericFunc: func(e event.GenericEvent) bool { return false },
+		DeleteFunc:  func(e event.DeleteEvent) bool { return true },
+		CreateFunc:  func(e event.CreateEvent) bool { return true },
+		UpdateFunc: func(e event.UpdateEvent) bool {
+			authRealmOld := e.ObjectOld.(*identitatemv1alpha1.AuthRealm)
+			authRealmNew := e.ObjectNew.(*identitatemv1alpha1.AuthRealm)
+			// only handle the Finalizer and Spec changes
+			return !equality.Semantic.DeepEqual(e.ObjectOld.GetFinalizers(), e.ObjectNew.GetFinalizers()) ||
+				!equality.Semantic.DeepEqual(authRealmOld.Spec, authRealmNew.Spec) ||
+				authRealmOld.DeletionTimestamp != authRealmNew.DeletionTimestamp
+
+		},
+	})
+
 	return ctrl.NewControllerManagedBy(mgr).
 		For(&clusterv1alpha1.Placement{}).
-		Watches(&source.Kind{Type: &identitatemv1alpha1.AuthRealm{}}, handler.EnqueueRequestsFromMapFunc(func(o client.Object) []reconcile.Request {
-			authrealm := o.(*identitatemv1alpha1.AuthRealm)
-			req := make([]reconcile.Request, 0)
-			// if authrealm.DeletionTimestamp != nil {
-			// 	r.Log.Info("authrealm changed but deletion timestamp set",
-			// 		"authrealm name", authrealm.Name,
-			// 		"authrealm namespace", authrealm.Namespace)
-			// 	return req
-			// }
-			strategies := &identitatemv1alpha1.StrategyList{}
-			if err := r.Client.List(context.TODO(), strategies, &client.ListOptions{Namespace: authrealm.Namespace}); err == nil {
-				for _, strategy := range strategies.Items {
-					placement := &clusterv1alpha1.Placement{}
-					if err := r.Client.Get(context.TODO(), client.ObjectKey{Name: strategy.Spec.PlacementRef.Name, Namespace: authrealm.Namespace}, placement); err != nil {
-						continue
-					}
-					r.Log.Info("Reconcile placement because authrealm changed",
-						"placement name", strategy.Spec.PlacementRef.Name,
-						"placement namespace", authrealm.Namespace,
-						"authrealm name", authrealm.Name,
-						"authrealm namespace", authrealm.Namespace)
-					req = append(req, reconcile.Request{
-						NamespacedName: types.NamespacedName{
-							Name:      strategy.Spec.PlacementRef.Name,
-							Namespace: authrealm.Namespace,
-						},
-					})
-				}
-			}
-			return req
-		})).
-		Watches(&source.Kind{Type: &dexoperatorv1alpha1.DexClient{}}, handler.EnqueueRequestsFromMapFunc(func(o client.Object) []reconcile.Request {
-			dexClient := o.(*dexoperatorv1alpha1.DexClient)
-			req := make([]reconcile.Request, 0)
-			for _, relatedObject := range dexClient.Status.RelatedObjects {
-				if relatedObject.Kind == "PlacementDecision" {
-					placementDecision := &clusterv1alpha1.PlacementDecision{}
-					if err := r.Client.Get(context.TODO(),
-						client.ObjectKey{Name: relatedObject.Name, Namespace: relatedObject.Namespace},
-						placementDecision); err == nil {
+		Watches(&source.Kind{Type: &identitatemv1alpha1.AuthRealm{}},
+			handler.EnqueueRequestsFromMapFunc(func(o client.Object) []reconcile.Request {
+				authrealm := o.(*identitatemv1alpha1.AuthRealm)
+				req := make([]reconcile.Request, 0)
+				strategies := &identitatemv1alpha1.StrategyList{}
+				if err := r.Client.List(context.TODO(),
+					strategies,
+					&client.ListOptions{Namespace: authrealm.Namespace}); err == nil {
+					for _, strategy := range strategies.Items {
+						placement := &clusterv1alpha1.Placement{}
+						if err := r.Client.Get(context.TODO(),
+							client.ObjectKey{
+								Name:      strategy.Spec.PlacementRef.Name,
+								Namespace: authrealm.Namespace},
+							placement); err != nil {
+							continue
+						}
+						r.Log.Info(fmt.Sprintf("Reconcile placement %s/%s because authrealm %s/%s changed",
+							placement.Name,
+							placement.Namespace,
+							authrealm.Name,
+							authrealm.Namespace))
 						req = append(req, reconcile.Request{
 							NamespacedName: types.NamespacedName{
-								Name:      placementDecision.Name,
-								Namespace: placementDecision.Namespace,
+								Name:      placement.Name,
+								Namespace: authrealm.Namespace,
 							},
 						})
 					}
 				}
-			}
-			return req
-		})).
-		//TODO Watch clientSecret to regenerate dexclient/clusterOAuth
+				return req
+			}),
+			builder.WithPredicates(authRealmPredicate)).
+		Watches(&source.Kind{Type: &dexoperatorv1alpha1.DexClient{}},
+			handler.EnqueueRequestsFromMapFunc(func(o client.Object) []reconcile.Request {
+				dexClient := o.(*dexoperatorv1alpha1.DexClient)
+				req := make([]reconcile.Request, 0)
+				for _, relatedObject := range dexClient.Status.RelatedObjects {
+					if relatedObject.Kind == "PlacementDecision" {
+						placementDecision := &clusterv1alpha1.PlacementDecision{}
+						if err := r.Client.Get(context.TODO(),
+							client.ObjectKey{Name: relatedObject.Name, Namespace: relatedObject.Namespace},
+							placementDecision); err == nil {
+							r.Log.Info(fmt.Sprintf("Reconcile placement %s/%s because dexclient %s/%s changed",
+								placementDecision.GetLabels()["cluster.open-cluster-management.io/placement"],
+								placementDecision.Namespace,
+								dexClient.Name,
+								dexClient.Namespace))
+							req = append(req, reconcile.Request{
+								NamespacedName: types.NamespacedName{
+									Name:      placementDecision.GetLabels()["cluster.open-cluster-management.io/placement"],
+									Namespace: placementDecision.Namespace,
+								},
+							})
+						}
+					}
+				}
+				return req
+			})).
 		Complete(r)
 }
