@@ -235,7 +235,6 @@ var _ = Describe("Process Strategy backplane: ", func() {
 			placement, err = clientSetCluster.ClusterV1alpha1().Placements(AuthRealmNameSpace).
 				Create(context.TODO(), placement, metav1.CreateOptions{})
 			Expect(err).To(BeNil())
-
 		})
 		var authRealm *identitatemv1alpha1.AuthRealm
 		By("creating a AuthRealm CR", func() {
@@ -271,6 +270,14 @@ var _ = Describe("Process Strategy backplane: ", func() {
 			//DV reassign  to authRealm to get the extra info that kube set (ie:uuid as needed to set ownerref)
 			authRealm, err = clientSetMgmt.IdentityconfigV1alpha1().AuthRealms(AuthRealmNameSpace).Create(context.TODO(), authRealm, metav1.CreateOptions{})
 			Expect(err).To(BeNil())
+			patch := client.MergeFrom(authRealm.DeepCopy())
+			authRealm.Status.Strategies = []identitatemv1alpha1.AuthRealmStrategyStatus{
+				{
+					Name: "my-authrealm-backplane",
+				},
+			}
+			err = k8sClient.Status().Patch(context.TODO(), authRealm, patch)
+			Expect(err).To(BeNil())
 		})
 		By(fmt.Sprintf("creation of Dex server namespace %s", AuthRealmName), func() {
 			ns := &corev1.Namespace{
@@ -314,7 +321,17 @@ var _ = Describe("Process Strategy backplane: ", func() {
 			placementStrategy, err = clientSetCluster.ClusterV1alpha1().Placements(AuthRealmNameSpace).
 				Create(context.TODO(), placementStrategy, metav1.CreateOptions{})
 			Expect(err).To(BeNil())
-
+			placementStrategy.Status.Conditions = make([]metav1.Condition, 0)
+			placementStrategy.Status.Conditions = append(placementStrategy.Status.Conditions, metav1.Condition{
+				Message:            "All cluster decisions scheduled",
+				Reason:             "AllDecisionsScheduled",
+				Type:               "PlacementSatisfied",
+				Status:             metav1.ConditionTrue,
+				LastTransitionTime: metav1.Now(),
+			})
+			placementStrategy.Status.NumberOfSelectedClusters = 1
+			placementStrategy, err = clientSetCluster.ClusterV1alpha1().Placements(AuthRealmNameSpace).UpdateStatus(context.TODO(), placementStrategy, metav1.UpdateOptions{})
+			Expect(err).To(BeNil())
 		})
 		By("creation cluster namespace", func() {
 			ns := &corev1.Namespace{
@@ -364,14 +381,22 @@ var _ = Describe("Process Strategy backplane: ", func() {
 		dexClientName := AuthRealmName
 		clientSecret := &corev1.Secret{}
 		By(fmt.Sprintf("Checking client secret %s", AuthRealmName), func() {
-			err := k8sClient.Get(context.TODO(), client.ObjectKey{Name: helpers.ClientSecretName(authRealm), Namespace: ClusterName}, clientSecret)
+			authRealmObjectKey := client.ObjectKey{
+				Name:      authRealm.Name,
+				Namespace: authRealm.Namespace,
+			}
+			err := k8sClient.Get(context.TODO(), client.ObjectKey{Name: helpers.ClientSecretName(authRealmObjectKey), Namespace: ClusterName}, clientSecret)
 			Expect(err).To(BeNil())
 		})
 		By(fmt.Sprintf("Checking DexClient %s", dexClientName), func() {
 			dexClient := &dexv1alpha1.DexClient{}
-			err := k8sClient.Get(context.TODO(), client.ObjectKey{Name: helpers.DexClientName(authRealm, ClusterName), Namespace: helpers.DexServerNamespace(authRealm)}, dexClient)
+			authRealmObjectKey := client.ObjectKey{
+				Name:      authRealm.Name,
+				Namespace: authRealm.Namespace,
+			}
+			err := k8sClient.Get(context.TODO(), client.ObjectKey{Name: helpers.DexClientName(authRealmObjectKey, ClusterName), Namespace: helpers.DexServerNamespace(authRealm)}, dexClient)
 			Expect(err).To(BeNil())
-			Expect(dexClient.Spec.ClientID).To(Equal(helpers.DexClientName(authRealm, ClusterName)))
+			Expect(dexClient.Spec.ClientID).To(Equal(helpers.DexClientName(authRealmObjectKey, ClusterName)))
 			Expect(dexClient.Spec.ClientSecretRef.Name).To(Equal(clientSecret.Name))
 			Expect(dexClient.Spec.ClientSecretRef.Namespace).To(Equal(clientSecret.Namespace))
 			Expect(len(dexClient.Status.RelatedObjects)).To(Equal(1))
@@ -379,7 +404,11 @@ var _ = Describe("Process Strategy backplane: ", func() {
 		})
 		By(fmt.Sprintf("Checking ClusterOAuth %s", dexClientName), func() {
 			clusterOAuth := &identitatemv1alpha1.ClusterOAuth{}
-			err := k8sClient.Get(context.TODO(), client.ObjectKey{Name: helpers.ClusterOAuthName(authRealm), Namespace: ClusterName}, clusterOAuth)
+			authRealmObjectKey := client.ObjectKey{
+				Name:      authRealm.Name,
+				Namespace: authRealm.Namespace,
+			}
+			err := k8sClient.Get(context.TODO(), client.ObjectKey{Name: helpers.ClusterOAuthName(authRealmObjectKey), Namespace: ClusterName}, clusterOAuth)
 			Expect(err).To(BeNil())
 			Expect(clusterOAuth.Spec.OAuth.Spec.IdentityProviders[0].OpenID.ClientID).To(Equal(fmt.Sprintf("%s-%s", ClusterName, AuthRealmName)))
 			Expect(clusterOAuth.Spec.OAuth.Spec.IdentityProviders[0].OpenID.ClientSecret.Name).To(Equal(clientSecret.Name))
